summaryrefslogtreecommitdiff
path: root/MdePkg/Library/SmmMemLib/SmmMemLib.c
diff options
context:
space:
mode:
Diffstat (limited to 'MdePkg/Library/SmmMemLib/SmmMemLib.c')
-rw-r--r--MdePkg/Library/SmmMemLib/SmmMemLib.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/MdePkg/Library/SmmMemLib/SmmMemLib.c b/MdePkg/Library/SmmMemLib/SmmMemLib.c
index 21f67d2..420c5a7 100644
--- a/MdePkg/Library/SmmMemLib/SmmMemLib.c
+++ b/MdePkg/Library/SmmMemLib/SmmMemLib.c
@@ -38,11 +38,11 @@ UINTN mSmmMemLibInternalSmramCount;
EFI_PHYSICAL_ADDRESS mSmmMemLibInternalMaximumSupportAddress = 0;
/**
- Caculate and save the maximum support address.
+ Calculate and save the maximum support address.
**/
VOID
-SmmMemLibInternalCaculateMaximumSupportAddress (
+SmmMemLibInternalCalculateMaximumSupportAddress (
VOID
)
{
@@ -315,9 +315,9 @@ SmmMemLibConstructor (
mSmmMemLibInternalSmramCount = Size / sizeof (EFI_SMRAM_DESCRIPTOR);
//
// Caculate and save maximum support address
//
- SmmMemLibInternalCaculateMaximumSupportAddress ();
+ SmmMemLibInternalCalculateMaximumSupportAddress ();
return EFI_SUCCESS;
}
@@ -315,9 +315,9 @@ SmmMemLibConstructor (
mSmmMemLibInternalSmramCount = Size / sizeof (EFI_SMRAM_DESCRIPTOR);
//
- // Caculate and save maximum support address
+ // Calculate and save maximum support address
//